<?php
namespace FiloBlu\Flow\Model\From;

class Price extends AbstractFrom {

    /**
     * @var \Monolog\Logger
     */
    protected $_logger;
    protected $_productFactory;
    protected $_productAction;

    /**
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Model\ResourceModel\AbstractResource $resource
     * @param \Magento\Framework\Data\Collection\Db $resourceCollection
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        \FiloBlu\Flow\Helper\Data $helper_flow,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Catalog\Model\ProductFactory $productFactory,
        array $data = []
    )
    {
        $this->_helper_flow = $helper_flow;
        $this->_storeManager = $storeManager;
        $this->_productFactory = $productFactory;
        $this->_productAction = \Magento\Framework\App\ObjectManager::getInstance()->get('Magento\Catalog\Model\Product\Action');
        $this->_configurableAction = \Magento\Framework\App\ObjectManager::getInstance()->create('Magento\ConfigurableProduct\Model\ResourceModel\Product\Type\Configurable');
        parent::__construct($context, $registry, null, null, $data);
    }

    /**
     * @return void
     */
    public function _construct()
    {
        $this->_init('FiloBlu\Flow\Model\ResourceModel\From\Price');
    }


    public function process() {

        $productSku = $this->getSku();
        $paese = $this->getPaese();
        $prezzo = $this->getPrezzo();

        if(trim($prezzo) == ""){
            $message = sprintf("Empty price! Skipping! product_code: '%s'", $this->getSku());
            return $this->error(false, $message);
        }

        $allStore = $this->_helper_flow->getStoreInWebsiteId();

        if(is_null($paese)){
            $paese = 'admin';
        }
        $storeId = $allStore[$paese]['store_id'];

        $productId = $this->_productFactory->create()->getIdBySku($productSku);

        if(!$productId){
            $message = sprintf("Product not found! product_code: '%s'", $this->getSku());
            return $this->error(false, $message);
        }

        if($productId){

            $pids[] = $productId;

            // salvo il prezzo sul prodotto configurabile padre
            $parent_product_id = $this->_configurableAction->getParentIdsByChild($productId);

            if(!empty($parent_product_id)){
                $pids = array_merge($pids, $parent_product_id);
            }

            try{
                $this->_productAction->updateAttributes(
                    $pids, array("price" => $prezzo), $storeId
                );
            }catch (\Exception $e){
                $message = "Problem while processing price,<br/> store id : ".$storeId."<br/> pids : ".print_r($pids,true). "<br/> attribute data : ".print_r($prezzo,true);
                $message .= "<br/> \Exception : ".$e->getMessage();
                $message .= "<br/> Backtrace : <br/> ".nl2br($e->getTraceAsString());
                throw new \Exception($e->getMessage());
            }



        }

        return $this;

    }


}
